| Title: | Assess the Diagnostic Power of Genomic Marker Combinations |
|---|---|
| Description: | Population genetics package for designing diagnostic panels. Candidate markers, marker combinations, and different panel sizes are assessed for how well they can predict the source population of known samples. Requires a genotype file of candidate markers in STRUCTURE format. Methods for population cross-validation are described in Jombart (2008) <doi:10.1093/bioinformatics/btn129>. |
| Authors: | Kim Vertacnik [cre, aut]
|
| Maintainer: | Kim Vertacnik <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.1.1 |
| Built: | 2026-05-16 07:16:20 UTC |
| Source: | https://github.com/cran/snpAIMeR |
Population genetics package for optimizing diagnostic panels. User-selected candidate markers are assessed individually and in combination for how well they can predict the source population of known samples. Requires a genotype file in STRUCTURE format.
snpAIMeR(run_mode, config_file = NULL, verbose = TRUE)snpAIMeR(run_mode, config_file = NULL, verbose = TRUE)
run_mode |
Modes are "interactive", "non-interactive", or "example"; mode must be in quotes. |
config_file |
Yaml file required for "non-interactive" mode; filename/path must be in quotes. |
verbose |
Default is TRUE. |
Yaml file format for "non-interactive" mode (do not include bullet points):
min_range: <minimum panel size>
max_range: <maximum panel size; we recommend no more than 15 markers>
assignment_rate_threshold: <value from 0 to 1>
cross_validation_replicates: <we recommend 100 minimum>
working_directory: <path name in quotes>
structure_file: <path name in quotes>
number_of_individuals: <same as adegenet's "n.ind">
number_of_loci: <same as adegenet's "n.loc">
one_data_row_per_individual: <TRUE or FALSE>
column_sample_IDs: <column number>
column_population_assignments: <column number>
column_other_info: <column number>
row_markernames: <row number>
no_genotype_character: <default is "-9">
optional_population_info: <optional>
genotype_character_separator: <optional>
Minimizing run time: Because of the number of possible combinations, we recommend testing no more than 15 markers. For example, testing 15 markers in panel sizes of 1 to 15 (32,767 total combinations) with 1,000 cross-validation replicates on a system with 48 processor cores took about 5 hours and 20 GB RAM. Reducing the number of cross-validation replicates will reduce run time, however, we recommend no less than 100 replicates.
Cross-validation assignment rates for individual markers, marker combinations, and panel sizes. Outputs three .csv and two .pdf files to a user-specified directory.
https://github.com/OksanaVe/snpAIMeR
if (requireNamespace("adegenet", quietly = TRUE)) { data(nancycats, package = "adegenet") snpAIMeR("example", verbose = TRUE) }if (requireNamespace("adegenet", quietly = TRUE)) { data(nancycats, package = "adegenet") snpAIMeR("example", verbose = TRUE) }